@@ -1,7 +1,7 @@
 package Proc::Find;
 
-our $DATE = '2015-01-03'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2019-11-23'; # DATE
+our $VERSION = '0.050'; # VERSION
 
 use 5.010001;
 use strict;
@@ -36,6 +36,7 @@ sub find_proc {
     my %args = @_;
 
     my @unknown_args = grep {!/\A(
+                                   filter|
                                    pid|name|cmndline|exec|
                                    user|uid|euser|euid|
                                    table|detail|
@@ -58,6 +59,10 @@ sub find_proc {
         my $cond = 0;
       COND:
         {
+            if (defined $args{filter}) {
+                local $_ = $p;
+                last COND unless $args{filter}->($p);
+            }
             if (defined $args{pid}) {
                 last COND unless $p->{pid} == $args{pid};
             }
@@ -199,7 +204,7 @@ Proc::Find - Find processes by name, PID, or some other attributes
 
 =head1 VERSION
 
-This document describes version 0.04 of Proc::Find (from Perl distribution Proc-Find), released on 2015-01-03.
+This document describes version 0.050 of Proc::Find (from Perl distribution Proc-Find), released on 2019-11-23.
 
 =head1 SYNOPSIS
 
@@ -244,6 +249,10 @@ Arguments:
 
 =over
 
+=item * filter => code
+
+Filter by a coderef. The coderef will receive the process record (hashref).
+
 =item * pid => int
 
 Find by PID. Note that if you only want to check whether a PID exists, there are
@@ -341,14 +350,6 @@ C<Proc::ProcessTable>'s C<table()> method once.
  # find all processes belonging to either user
  find_any_proc([{user=>'ujang'}, {user=>'titin'}]);
 
-=head1 SEE ALSO
-
-L<Proc::Exists> can be used to check if one or more PIDs exist. If you are only
-concerned with POSIX systems, you can just do C<kill 0, $pid> to accomplish the
-same.
-
-B<pgrep> Unix command.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Proc-Find>.
@@ -365,13 +366,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Proc::Exists> can be used to check if one or more PIDs exist. If you are only
+concerned with POSIX systems, you can just do C<kill 0, $pid> to accomplish the
+same.
+
+B<pgrep> Unix command.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
